@@ -7,7 +7,7 @@ def get_name():
     return random.choice(["Deadpool", "Rick", "Morty", "Hiro"])
 
 
-def main(name: str = typer.Argument(get_name)):
+def main(name: str = typer.Argument(default_factory=get_name)):
     print(f"Hello {name}")
 
 
