@@ -1,3 +1,5 @@
+from typing import Optional
+
 import typer
 
 
@@ -10,7 +12,7 @@ def name_callback(ctx: typer.Context, param: typer.CallbackParam, value: str):
     return value
 
 
-def main(name: str = typer.Option(..., callback=name_callback)):
+def main(name: Optional[str] = typer.Option(default=None, callback=name_callback)):
     print(f"Hello {name}")
 
 
