@@ -3,9 +3,9 @@ import typer
 
 def main(username: str):
     if username == "root":
-        typer.echo("The root user is reserved")
+        print("The root user is reserved")
         raise typer.Abort()
-    typer.echo(f"New user created: {username}")
+    print(f"New user created: {username}")
 
 
 if __name__ == "__main__":
