@@ -22,7 +22,7 @@ def test_help():
 
 def test_call_no_arg():
     greetings = ["Hello Deadpool", "Hello Rick", "Hello Morty", "Hello Hiro"]
-    for i in range(3):
+    for _i in range(3):
         result = runner.invoke(app)
         assert result.exit_code == 0
         assert any(greet in result.output for greet in greetings)
@@ -37,8 +37,7 @@ def test_call_arg():
 def test_script():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
     )
     assert "Usage" in result.stdout
