@@ -19,7 +19,8 @@ def test_not_exists(tmpdir):
         config_file.unlink()
     result = runner.invoke(app, ["--config", f"{config_file}"])
     assert result.exit_code != 0
-    assert "Invalid value for '--config': File" in result.output
+    assert "Invalid value for '--config'" in result.output
+    assert "File" in result.output
     assert "does not exist" in result.output
 
 
@@ -35,7 +36,8 @@ def test_exists(tmpdir):
 def test_dir():
     result = runner.invoke(app, ["--config", "./"])
     assert result.exit_code != 0
-    assert "Invalid value for '--config': File './' is a directory." in result.output
+    assert "Invalid value for '--config'" in result.output
+    assert "File './' is a directory." in result.output
 
 
 def test_script():
